@@ -7,6 +7,7 @@ use Mojo::IOLoop;
 use Mojo::JSON 'to_json';
 use Mojo::Pg::Results;
 use Mojo::Pg::Transaction;
+use Mojo::Promise;
 use Mojo::Util 'monkey_patch';
 use Scalar::Util 'weaken';
 
@@ -115,7 +116,7 @@ sub query {
 
 sub query_p {
   my $self    = shift;
-  my $promise = Mojo::IOLoop->delay;
+  my $promise = Mojo::Promise->new;
   $self->query(
     @_ => sub { $_[1] ? $promise->reject($_[1]) : $promise->resolve($_[2]) });
   return $promise;
@@ -307,8 +308,7 @@ L<SQL::Abstract>.
   my $promise = $db->delete_p($table, \%where, \%options);
 
 Same as L</"delete">, but performs all operations non-blocking and returns a
-L<Mojo::IOLoop::Delay> object to be used as a promise instead of accepting a
-callback.
+L<Mojo::Promise> object to be used as a promise instead of accepting a callback.
 
   $db->delete_p('some_table')->then(sub {
     my $results = shift;
@@ -369,8 +369,7 @@ L<SQL::Abstract>.
   my $promise = $db->insert_p($table, \@values || \%fieldvals, \%options);
 
 Same as L</"insert">, but performs all operations non-blocking and returns a
-L<Mojo::IOLoop::Delay> object to be used as a promise instead of accepting a
-callback.
+L<Mojo::Promise> object to be used as a promise instead of accepting a callback.
 
   $db->insert_p(some_table => {foo => 'bar'})->then(sub {
     my $results = shift;
@@ -452,8 +451,7 @@ used to bind specific L<DBD::Pg> data types to placeholders.
   my $promise = $db->query_p('select * from foo');
 
 Same as L</"query">, but performs all operations non-blocking and returns a
-L<Mojo::IOLoop::Delay> object to be used as a promise instead of accepting a
-callback.
+L<Mojo::Promise> object to be used as a promise instead of accepting a callback.
 
   $db->query_p('insert into foo values (?, ?, ?)' => @values)->then(sub {
     my $results = shift;
@@ -500,8 +498,7 @@ L<SQL::Abstract>.
   my $promise = $db->select_p($source, $fields, $where, $order);
 
 Same as L</"select">, but performs all operations non-blocking and returns a
-L<Mojo::IOLoop::Delay> object to be used as a promise instead of accepting a
-callback.
+L<Mojo::Promise> object to be used as a promise instead of accepting a callback.
 
   $db->select_p(some_table => ['foo'] => {bar => 'yada'})->then(sub {
     my $results = shift;
@@ -562,7 +559,7 @@ L<SQL::Abstract>.
   my $promise = $db->update_p($table, \%fieldvals, \%where, \%options);
 
 Same as L</"update">, but performs all operations non-blocking and returns a
-L<Mojo::IOLoop::Delay> object to be used as a promise instead of accepting a
+L<Mojo::Promise> object to be used as a promise instead of accepting a
 callback.
 
   $db->update_p(some_table => {foo => 'baz'} => {foo => 'bar'})->then(sub {
